==> moodle-1.4.5.tgz: moodle/lang/zh_tw_utf8/forum.php <==
<?PHP // $Id: forum.php,v 1.1.8.1 2004/12/17 16:23:37 moodler Exp $ 
      // forum.php - created with Moodle 1.2 Beta (2004022400)


$string['addanewdiscussion'] = '新增一個討論主題';
$string['addanewtopic'] = '新增一個主題';
$string['allowchoice'] = '允許所有人選擇';
$string['allowdiscussions'] = '設定學生張貼權限';
$string['allowratings'] = '允許對張貼內容評比嗎?';
$string['allowsdiscussions'] = '本討論區允許每個人新增討論主題.';
$string['anyfile'] = '任何檔案';
$string['attachment'] = '附件';
$string['bynameondate'] = '由 $a->name 發表於- $a->date';
$string['configdisplaymode'] = '若未選擇顯示，將採用預設的顯示模式';
$string['configlongpost'] = '任何的發表文章超過這個長度，將被認定為太長';
$string['configmanydiscussions'] = '每頁最大顯示文章筆數';
$string['configmaxbytes'] = '預設的最大附件檔案容量大小';
$string['configshortpost'] = '任何的文章發表小於這個長度，將被認為過短，有灌水之嫌';
$string['couldnotadd'] = '由於不明錯誤, 無法張貼你的討論內容';
$string['couldnotdeleteratings'] = '抱歉, 本討論已被評比過, 故無法刪除';
$string['couldnotdeletereplies'] = '抱歉, 本討論主題已經有人回應, 故無法刪除';
$string['couldnotupdate'] = '由於不明錯誤,無法更新你的留言';
$string['delete'] = '刪除';
$string['deleteddiscussion'] = '本討論主題已被刪除';
$string['deletedpost'] = '本留言內容已被刪除';
$string['deletesure'] = '確定要刪除本留言嗎?';
$string['discussion'] = '討論';
$string['discussionmoved'] = '這個討論區被移至 $a';
$string['discussions'] = '討論';
$string['discussionsstartedby'] = '本討論由 $a 發起';
$string['discussionsstartedbyrecent'] = '最近的討論由 $a 所發起';
$string['discussthistopic'] = '討論本主題';
$string['eachuserforum'] = '每人僅限發表一主題';
$string['edit'] = '編輯';
$string['editing'] = '編輯中';
$string['emptymessage'] = '留言內容有誤.  若非空白便是附件檔案過大.  你的修改並未被儲存(更新).';
$string['everyonecanchoose'] = '每人可選擇是否訂閱 ';
$string['everyoneissubscribed'] = '每人都被設定訂閱本討論區';
$string['forcesubscribe'] = '強迫每個人都訂閱 ';
$string['forcesubscribeq'] = '強迫每個人都訂閱嗎?';
$string['forum'] = '討論區';
$string['forumintro'] = '討論區簡介';
$string['forumname'] = '討論區名稱';
$string['forums'] = '討論區';
$string['forumtype'] = '討論區型態';
$string['generalforum'] = '一般用途的標準討論區';
$string['generalforums'] = '一般討論區';
$string['inforum'] = '在 $a 裡';
$string['intronews'] = '一般通告與新聞';
$string['introsocial'] = '一個開放可隨意聊聊的討論區';
$string['introteacher'] = '僅限教師可參與討論區';
$string['lastpost'] = '最新文章';
$string['learningforums'] = '學習討論區';
$string['maxattachmentsize'] = '最大附件大小';
$string['maxtimehaspassed'] = '抱歉, 超過可編輯本留言 ($a) 的時限!';
$string['message'] = '訊息';
$string['modeflatnewestfirst'] = '表列回應內容, 最新張貼在前';
$string['modeflatoldestfirst'] = '表列回應內容, 早先張貼在前';
$string['modenested'] = '回應訊息將往右縮排';
$string['modethreaded'] = '回應訊息以樹狀結構呈現';
$string['modulename'] = '討論區';
$string['modulenameplural'] = '討論區';
$string['more'] = '還有';
$string['movethisdiscussionto'] = '搬移這個討論主題至 ...';
$string['namenews'] = '新聞討論區';
$string['namesocial'] = '公開討論區';
$string['nameteacher'] = '教師專屬討論區';
$string['newforumposts'] = '討論區最新張貼';
$string['nodiscussions'] = '本討論區尚未有任何留言';
$string['noguestpost'] = '抱歉, 訪客身分無法留言';
$string['nomorepostscontaining'] = '沒有搜尋到包含 $a  的文章';
$string['nonews'] = '目前沒有新發表的文章';
$string['noposts'] = '無任何相關留言';
$string['nopostscontaining'] = '找不到關於 $a 的留言';
$string['nosubscribers'] = '尚未有人訂閱本討論區';
$string['notingroup'] = '抱歉，你必需是這個群組的成員才可看這個板面';
$string['nownotsubscribed'] = '$a->name 將<B>不會</B>收到複製 $a->forum 留言內容的電子郵件.';
$string['nowsubscribed'] = '$a->name 將<B>會</B>收到複製 $a->forum 留言內容的電子郵件.';
$string['numposts'] = '$a 留言數';
$string['olderdiscussions'] = '過期討論';
$string['openmode0'] = '不能新增主題或回應留言';
$string['openmode1'] = '不能新增主題, 但可以回應留言';
$string['openmode2'] = '允許新增主題或回應留言';
$string['parent'] = '顯示上層文章';
$string['parentofthispost'] = '本留言回應的上一篇討論';
$string['postadded'] = '你的留言已成功加入討論區.<P>你有 $a 可以修改留言內容.';
$string['postincontext'] = '檢視本留言內容';
$string['postmailinfo'] = '這是張貼在 $a 網站的一篇留言.
請按以下連結以便回應此留言內容:';
$string['postrating1'] = '極端獨立型';
$string['postrating2'] = '折衷型';
$string['postrating3'] = '極端交流型';
$string['posts'] = '發表文章';
$string['postupdated'] = '已經更新你的留言';
$string['processingpost'] = '處理留言 $a';
$string['rate'] = '評比';
$string['rating'] = '評分';
$string['ratingeveryone'] = '所有人都能評比文章';
$string['ratingno'] = '尚無評比';
$string['ratingonlyteachers'] = '只有 $a 可以評比';
$string['ratingpublic'] = '$a 可以看到所有人的評比結果';
$string['ratingpublicnot'] = '$a 僅能看針對自己的評比';
$string['ratings'] = '評比';
$string['ratingssaved'] = '儲存評比結果';
$string['ratingsuse'] = '開放評比';
$string['ratingtime'] = '該時間段內限制評分';
$string['re'] = '回應:';
$string['readtherest'] = '閱覽本區其他留言';
$string['replies'] = '回覆';
$string['repliesmany'] = '至今有 $a 篇回應';
$string['repliesone'] = '至今有 $a 篇回應';
$string['reply'] = '回應';
$string['replyforum'] = '回覆文章';
$string['search'] = '搜尋';
$string['searchforums'] = '搜尋討論區';
$string['searcholderposts'] = '搜尋文章';
$string['searchresults'] = '搜尋結果';
$string['sendinratings'] = '送出最近的評比';
$string['showsubscribers'] = '顯示訂閱者';
$string['singleforum'] = '單一簡單討論主題';
$string['startedby'] = '開始於';
$string['subject'] = '主題';
$string['subscribe'] = '訂閱本討論區';
$string['subscribed'] = '訂閱 ';
$string['subscribers'] = '訂閱者';
$string['subscribersto'] = '訂閱 $a';
$string['subscribestart'] = '寄回討論區文章至我的電子郵件信箱';
$string['subscribestop'] = '不要寄回討論發文章至我的電子郵件信箱';
$string['subscription'] = '訂閱 ';
$string['subscriptions'] = '訂閱 ';
$string['unsubscribe'] = '取消訂閱 本討論區 ';
$string['unsubscribed'] = '取消訂閱 ';
$string['youratedthis'] = '你對此的評比是';
$string['yournewtopic'] = '你的新討論主題';
$string['yourreply'] = '你的回應內容';

?>

==> moodle-1.5.3.tgz: moodle/lang/zh_tw_utf8/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.2 Beta (2004022400)


$string['addanewdiscussion'] = '新增一個討論主題';
$string['addanewtopic'] = '新增一個主題';
$string['allowchoice'] = '允許所有人選擇';
$string['allowdiscussions'] = '設定學生張貼權限';
$string['allowratings'] = '允許對張貼內容評比嗎?';
$string['allowsdiscussions'] = '本討論區允許每個人新增討論主題.';
$string['anyfile'] = '任何檔案';
$string['attachment'] = '附件';
$string['bynameondate'] = '由 $a->name 發表於- $a->date';
$string['configdisplaymode'] = '若未選擇顯示，將採用預設的顯示模式';
$string['configlongpost'] = '任何的發表文章超過這個長度，將被認定為太長';
$string['configmanydiscussions'] = '每頁最大顯示文章筆數';
$string['configmaxbytes'] = '預設的最大附件檔案容量大小';
$string['configshortpost'] = '任何的文章發表小於這個長度，將被認為過短，有灌水之嫌';
$string['couldnotadd'] = '由於不明錯誤, 無法張貼你的討論內容';
$string['couldnotdeleteratings'] = '抱歉, 本討論已被評比過, 故無法刪除';
$string['couldnotdeletereplies'] = '抱歉, 本討論主題已經有人回應, 故無法刪除';
$string['couldnotupdate'] = '由於不明錯誤,無法更新你的留言';
$string['delete'] = '刪除';
$string['deleteddiscussion'] = '本討論主題已被刪除';
$string['deletedpost'] = '本留言內容已被刪除';
$string['deletesure'] = '確定要刪除本留言嗎?';
$string['discussion'] = '討論';
$string['discussionmoved'] = '這個討論區被移至 $a';
$string['discussions'] = '討論';
$string['discussionsstartedby'] = '本討論由 $a 發起';
$string['discussionsstartedbyrecent'] = '最近的討論由 $a 所發起';
$string['discussthistopic'] = '討論本主題';
$string['eachuserforum'] = '每人僅限發表一主題';
$string['edit'] = '編輯';
$string['editing'] = '編輯中';
$string['emptymessage'] = '留言內容有誤.  若非空白便是附件檔案過大.  你的修改並未被儲存(更新).';
$string['everyonecanchoose'] = '每人可選擇是否訂閱 ';
$string['everyoneissubscribed'] = '每人都被設定訂閱本討論區';
$string['forcesubscribe'] = '強迫每個人都訂閱 ';
$string['forcesubscribeq'] = '強迫每個人都訂閱嗎?';
$string['forum'] = '討論區';
$string['forumintro'] = '討論區簡介';
$string['forumname'] = '討論區名稱';
$string['forums'] = '討論區';
$string['forumtype'] = '討論區型態';
$string['generalforum'] = '一般用途的標準討論區';
$string['generalforums'] = '一般討論區';
$string['inforum'] = '在 $a 裡';
$string['intronews'] = '一般通告與新聞';
$string['introsocial'] = '一個開放可隨意聊聊的討論區';
$string['introteacher'] = '僅限教師可參與討論區';
$string['lastpost'] = '最新文章';
$string['learningforums'] = '學習討論區';
$string['maxattachmentsize'] = '最大附件大小';
$string['maxtimehaspassed'] = '抱歉, 超過可編輯本留言 ($a) 的時限!';
$string['message'] = '訊息';
$string['modeflatnewestfirst'] = '表列回應內容, 最新張貼在前';
$string['modeflatoldestfirst'] = '表列回應內容, 早先張貼在前';
$string['modenested'] = '回應訊息將往右縮排';
$string['modethreaded'] = '回應訊息以樹狀結構呈現';
$string['modulename'] = '討論區';
$string['modulenameplural'] = '討論區';
$string['more'] = '還有';
$string['movethisdiscussionto'] = '搬移這個討論主題至 ...';
$string['namenews'] = '新聞討論區';
$string['namesocial'] = '公開討論區';
$string['nameteacher'] = '教師專屬討論區';
$string['newforumposts'] = '討論區最新張貼';
$string['nodiscussions'] = '本討論區尚未有任何留言';
$string['noguestpost'] = '抱歉, 訪客身分無法留言';
$string['nomorepostscontaining'] = '沒有搜尋到包含 $a  的文章';
$string['nonews'] = '目前沒有新發表的文章';
$string['noposts'] = '無任何相關留言';
$string['nopostscontaining'] = '找不到關於 $a 的留言';
$string['nosubscribers'] = '尚未有人訂閱本討論區';
$string['notingroup'] = '抱歉，你必需是這個群組的成員才可看這個板面';
$string['nownotsubscribed'] = '$a->name 將<b>不會</b>收到複製 $a->forum 留言內容的電子郵件.';
$string['nowsubscribed'] = '$a->name 將<b>會</b>收到複製 $a->forum 留言內容的電子郵件.';
$string['numposts'] = '$a 留言數';
$string['olderdiscussions'] = '過期討論';
$string['openmode0'] = '不能新增主題或回應留言';
$string['openmode1'] = '不能新增主題, 但可以回應留言';
$string['openmode2'] = '允許新增主題或回應留言';
$string['parent'] = '顯示上層文章';
$string['parentofthispost'] = '本留言回應的上一篇討論';
$string['postadded'] = '你的留言已成功加入討論區.<br />你有 $a 可以修改留言內容.';
$string['postincontext'] = '檢視本留言內容';
$string['postmailinfo'] = '這是張貼在 $a 網站的一篇留言.
請按以下連結以便回應此留言內容:';
$string['postrating1'] = '極端獨立型';
$string['postrating2'] = '折衷型';
$string['postrating3'] = '極端交流型';
$string['posts'] = '發表文章';
$string['postupdated'] = '已經更新你的留言';
$string['processingpost'] = '處理留言 $a';
$string['rate'] = '評比';
$string['rating'] = '評分';
$string['ratingeveryone'] = '所有人都能評比文章';
$string['ratingno'] = '尚無評比';
$string['ratingonlyteachers'] = '只有 $a 可以評比';
$string['ratingpublic'] = '$a 可以看到所有人的評比結果';
$string['ratingpublicnot'] = '$a 僅能看針對自己的評比';
$string['ratings'] = '評比';
$string['ratingssaved'] = '儲存評比結果';
$string['ratingsuse'] = '開放評比';
$string['ratingtime'] = '該時間段內限制評分';
$string['re'] = '回應:';
$string['readtherest'] = '閱覽本區其他留言';
$string['replies'] = '回覆';
$string['repliesmany'] = '至今有 $a 篇回應';
$string['repliesone'] = '至今有 $a 篇回應';
$string['reply'] = '回應';
$string['replyforum'] = '回覆文章';
$string['search'] = '搜尋';
$string['searchforums'] = '搜尋討論區';
$string['searcholderposts'] = '搜尋文章';
$string['searchresults'] = '搜尋結果';
$string['sendinratings'] = '送出最近的評比';
$string['showsubscribers'] = '顯示訂閱者';
$string['singleforum'] = '單一簡單討論主題';
$string['startedby'] = '開始於';
$string['subject'] = '主題';
$string['subscribe'] = '訂閱本討論區';
$string['subscribed'] = '訂閱 ';
$string['subscribers'] = '訂閱者';
$string['subscribersto'] = '訂閱 $a';
$string['subscribestart'] = '寄回討論區文章至我的電子郵件信箱';
$string['subscribestop'] = '不要寄回討論發文章至我的電子郵件信箱';
$string['subscription'] = '訂閱 ';
$string['subscriptions'] = '訂閱 ';
$string['unsubscribe'] = '取消訂閱 本討論區 ';
$string['unsubscribed'] = '取消訂閱 ';
$string['youratedthis'] = '你對此的評比是';
$string['yournewtopic'] = '你的新討論主題';
$string['yourreply'] = '你的回應內容';

?>
